@@ -19,7 +19,7 @@ import shutil
 import numpy as np
 import numpy.typing as npt
 
-from amarium.checks import check_make_file_name_suffix, check_make_dir
+from .checks import check_make_file_name_suffix, check_make_dir
 
 LOGGER = logging.getLogger(__name__)
 
@@ -33,7 +33,7 @@ def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
     :param file_name:str: Used to Specify the name of the file to be saved.
     :return: The full path of the file name.
 
-    :doc-author: Trelent
+    :doc-author: Julian M. Kleber
     """
     check_make_dir(prefix)
     file_name = make_full_filename(prefix, file_name)
@@ -238,10 +238,11 @@ def write_tar(target_dir: str, file_name: str) -> None:
     """
 
     with tarfile.open(file_name, "w") as tar:
-        for root, dir, files in os.walk(target_dir):
+        for root, directory, files in os.walk(target_dir):
             for file in files:
                 fullpath = os.path.join(root, file)
                 tar.add(fullpath, arcname=file)
+            del directory
         tar.close()
 
 
